pub enum Error {
Show 20 variants
ExpectedSpeedOnFPL,
ExpectedLevelOnFPL,
UnexpectedRouteToken(String),
UnexpectedRunwayInRoute(String),
UnknownRunwayInRoute {
arpt: String,
rwy: String,
},
AmbiguousTerminalArea {
wp: String,
a: String,
b: String,
},
InvalidA424 {
record: Vec<u8>,
error: String,
},
UnexpectedString,
ImplausibleValue,
UnknownLocationIndicator(String),
UnknownIdent(String),
InvalidRWYCC,
UnexpectedMassesForStations,
UnexpectedNumberOfFuelStations,
ExceededFuelCapacityOnRamp,
ExceededFuelCapacityAfterLanding,
ExpectedRegistration,
ExpectedEmptyMass,
ExpectedEmptyBalance,
ExpectedFuelType,
}Variants
ExpectedSpeedOnFPL
The entered flight plan does not include a cruise speed as one of the first two elements.
ExpectedLevelOnFPL
The entered flight plan does not include a cruise level as one of the first two elements.
UnexpectedRouteToken(String)
The route prompt includes a token that was not expected.
UnexpectedRunwayInRoute(String)
The route includes a runway at a position that is not next to an airport.
UnknownRunwayInRoute
The route includes a runway that is not found on the associated airport.
AmbiguousTerminalArea
A terminal waypoint needs to match to exactly one of the terminal areas in scope.
InvalidA424
The ARINC 424 navigation data record is invalid.
UnexpectedString
The string that should be parsed to create some type is malformed.
ImplausibleValue
The value that should be returned is implausible.
UnknownLocationIndicator(String)
The location indicator should be a two-letter code according to ICAO Document No. 7910.
UnknownIdent(String)
The requested identifier is not know.
InvalidRWYCC
The RWYCC should be between 0 and 6.
UnexpectedMassesForStations
The number of masses doesn’t match the number of stations to which the masses are assigned.
UnexpectedNumberOfFuelStations
The number of provided fuel stations doesn’t match the aircraft’s fuel stations.
ExceededFuelCapacityOnRamp
The planned fuel on ramp exceeds the tank’s capacity.
ExceededFuelCapacityAfterLanding
The planned fuel after landing exceeds the tank’s capacity.
ExpectedRegistration
The aircraft’s registration is not set.
ExpectedEmptyMass
The aircraft’s empty mass is not set.
ExpectedEmptyBalance
The aircraft’s empty balance is not set.
ExpectedFuelType
The aircraft’s fuel type is not set.