Struct FMS

pub struct FMS { /* private fields */ }

Implementations

Source

impl FMS

pub fn new() -> Self

Constructs a new, empty FMS.

pub fn nd(&mut self) -> &mut NavigationData

pub fn route(&mut self) -> &mut Route

pub fn decode(&mut self, route: &str) -> Result<(), Error>

pub fn set_alternate(&mut self, ident: &str) -> Result<(), Error>

Sets an alternate on the route.

Returns an UnknownIdent error if no NavAid is found for the ident within the navigation data.

pub fn build_flight_planning( &mut self, builder: &FlightPlanningBuilder, ) -> Result<(), Error>

pub fn flight_planning(&self) -> Option<&FlightPlanning>

pub fn print(&mut self, line_length: usize) -> String

Prints the route and planning with a defined line length.