MassAndBalance

Struct MassAndBalance 

pub struct MassAndBalance { /* private fields */ }
The mass & balance on ramp and after landing.

The mass and balance of the Aircraft is computed from Stations loaded on the aircraft. The mass is computed as sum of all station’s mass and the balance is the sum of all moment divided by the total mass.

Implementations

Source

impl MassAndBalance

pub fn new(loaded_stations: &Vec<LoadedStation>) -> Self

Computes the mass & balance from loaded stations.

Note: The stations must define all mass of the aircraft. This includes the empty mass, fuel tanks and removable mass.

pub fn mass_on_ramp(&self) -> &Mass

pub fn mass_after_landing(&self) -> &Mass

pub fn balance_on_ramp(&self) -> &Length

pub fn balance_after_landing(&self) -> &Length