pub enum RunwayConditionCode {
Six,
Five,
Four,
Three,
Two,
One,
Zero,
}Variants
Six
Dry.
Five
Frost, wet, slush, dry snow or wet snow.
Four
Compacted snow.
Three
Wet (slippery), dry snow, wet snow, dry snow on top of compacted snow, wet snow on top of compacted snow or compacted snow.
Two
Standing water or slush.
One
Ice.
Zero
Wet ice, water on top of compacted snow or dry snow or wet snow on top of ice.