Module route

Module route 

Structs

AirspaceIntersection
An intersection of a route with an airspace.
Leg
A leg from one point to another.
Route
A route that goes from an origin to a destination.
Token
TotalsToLeg
Cumulative totals up to a leg.
VerticalProfile
Vertical profile of a route with airspaces intersected by the route.

Enums

TokenKind
Semantic token representing a resolved route element.
VerticalPoint
A point of interest on the vertical profile of a route.