#[repr(C)]pub struct Fuel {
pub fuel_type: FuelType,
pub mass: Mass,
}Expand description
Fuel quantity with a specific type and mass.
Represents a quantity of fuel, tracking both the fuel type and mass. Fuel quantities can be created from either mass or volume, and converted between the two at ISA conditions.
Examples
// Create fuel from volume
let fuel = Fuel::from_volume(Volume::l(100.0), FuelType::Diesel);
// Create fuel from mass
let fuel = Fuel::new(Mass::kg(83.8), FuelType::Diesel);
// Add fuel quantities
let total = Fuel::from_volume(Volume::l(50.0), FuelType::Diesel)
+ Fuel::from_volume(Volume::l(50.0), FuelType::Diesel);
assert_eq!(total.volume(), Volume::l(100.0));Fields
fuel_type: FuelTypemass: MassImplementations