The Electronic Flight Bag (EFB) Library
The EFB Library is the foundation for flight planning applications, providing functionality to plan a flight and get navigational aids in-flight.
Overview
At the core of the EFB is the FMS. It holds the navigation data,
route and delegates the flight planning. The following example shows the
simplest planning:
use efb::prelude::*;
// create the FMS
let mut fms = FMS::new();
// Read navigation data from ARINC 424 records. Here we have the two airports
// EDDH (Hamburg) with the runway 33 and EDHF (Itzehoe) with runway 20.
let records = r#"SEURP EDDHEDA 0 N N53374900E009591762E002000053 P MWGE HAMBURG 356462409
SEURP EDDHEDGRW33 0120273330 N53374300E009595081 151 124362502
SEURP EDHFEDA 0 N N53593300E009343600E000000082 P MWGE ITZEHOE/HUNGRIGER WOLF 320782409
SEURP EDHFEDGRW20 0034122060 N53594752E009344856 098 120792502
"#;
let example_nd = NavigationData::try_from_arinc424(records)?;
fms.modify_nd(|nd| nd.append(example_nd))?;
// Now we can decode a Route from EDDH to EDHF with takeoff runway 33 and
// landing runway 20. Cruise speed is 107kt at an cruise altitude of 2500ft.
// The wind is 20kt from 290°.
fms.decode("29020KT N0107 A0250 EDDH RWY33 EDHF RWY20".to_string())?;From here we can start to define a FlightPlanningBuilder that holds all
information required to let the FMS build a flight planning.
Acronyms & Abbreviations
Aviation if full of Acronyms. To not lose track between FMS and RWY, the following section covers acronyms used within this crate.
A
- AFM Aircraft Flight Manual
E
- EFB Electronic Flight Bag
- Elev Elevation
F
- FMS Flight Management System
I
- ISA International Standard Atmosphere
M
- MSL Mean Sea Level
P
- POH Pilot Operation Handbook
Q
- QNH Pressure measured at a location and reduced down to MSL
R
- RWY Runway
- RWYCC Runway Condition Code
Modules
- aircraft
- An aircraft to plan and fly with.
- algorithm
- Algorithms.
- error
- EFB error types.
- fc
- Flight Computer.
- fms
- Flight Management System.
- fp
- Flight Planning.
- geojson
geojson - geom
- Geometry.
- macros
- measurements
- Measurement of physical quantities.
- nd
- Navigation Data.
- prelude
- route
Macros
- avgas
- Creates AvGas
Fuelfrom theVolumeat ISA conditions. - coord
- Creates a
Coordinate. - diesel
- Creates Diesel
Fuelfrom theVolumeat ISA conditions. - jet_a
- Creates Jet-A
Fuelfrom theVolumeat ISA conditions. - polygon
- Creates a
Polygoncontaining the coordinates.
Structs
Enums
- Fuel
Flow - Fuel
Type - Type of fuel used by an aircraft.
- Magnetic
Variation - The magnetic variation (declination) of a point.
- Vertical
Distance - A vertical distance.