pub struct MassAndBalance { /* private fields */ }Expand description
Implementations
Sourceimpl MassAndBalance
impl MassAndBalance
Sourcepub fn new(loaded_stations: &Vec<LoadedStation>) -> Self
pub fn new(loaded_stations: &Vec<LoadedStation>) -> Self
Computes the mass & balance from loaded stations.
Note: The stations must define all mass of the aircraft. This includes the empty mass, fuel tanks and removable mass.
pub fn mass_on_ramp(&self) -> &Mass
pub fn mass_after_landing(&self) -> &Mass
pub fn balance_on_ramp(&self) -> &Length
pub fn balance_after_landing(&self) -> &Length