Structs
- Airspace
Intersection - An intersection of a route with an airspace.
- Leg
- A leg
fromone pointtoanother. - Route
- A route that goes from an origin to a destination.
- Token
- Totals
ToLeg - Cumulative totals up to a leg.
- Vertical
Profile - Vertical profile of a route with airspaces intersected by the route.
Enums
- Token
Kind - Semantic token representing a resolved route element.
- Vertical
Point - A point of interest on the vertical profile of a route.